from concurrent import futures
import math
import time

PRIMES = [
      100000000000000,
      112272535095293,
      112582705942171,
      112272535095293,
      200000000000000,
      115797848077099,
      1099726899285419]


def is_prime(n):
    if n % 2 == 0:
        return False
    top = int(math.sqrt(n)) + 1
    for x in range(3, top, 2):
        if n % x == 0:
            return False
    return True


def inner_loop(executor, exec_type):
    """Inner loop of primes example"""
    start = time.time()
    for number, prime in zip(PRIMES, executor.map(is_prime, PRIMES)):
        if prime:
            print('%d is prime' % number)
        else:
            print('%d is not prime' % number)
    print('%s pool wall clock time: %f' % (exec_type, time.time() - start))


def main():
    with futures.ProcessPoolExecutor() as executor:
        inner_loop(executor, 'Process')

    with futures.ThreadPoolExecutor(max_workers=4) as executor:
        inner_loop(executor, 'Thread')


if __name__ == '__main__':
    main()
